summaryrefslogtreecommitdiffstats
path: root/ui/views/view_unittest.cc
diff options
context:
space:
mode:
authorbenrg@chromium.org <benrg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-24 04:33:20 +0000
committerbenrg@chromium.org <benrg@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-24 04:33:20 +0000
commit4bd6e19b07e43baa70da95d59a7bd6f47f5bf262 (patch)
tree13ad114e3d1c60ae1269f8afdf9bdf6c839058c6 /ui/views/view_unittest.cc
parent22f58a413b507463f97804a947c732d9a1c7eec6 (diff)
downloadchromium_src-4bd6e19b07e43baa70da95d59a7bd6f47f5bf262.zip
chromium_src-4bd6e19b07e43baa70da95d59a7bd6f47f5bf262.tar.gz
chromium_src-4bd6e19b07e43baa70da95d59a7bd6f47f5bf262.tar.bz2
Rename visual style "password" to "obscured"
This change renames some identifiers to distinguish the visual style of being drawn **** **** from the logical property of being a password. It is split off from issue 8748001 and issue 8747001. See http://codereview.chromium.org/8748001/#msg12 and http://codereview.chromium.org/8748001/#msg14 for discussion of the name. TEXT_INPUT_TYPE_PASSWORD is unchanged; it should perhaps be renamed, but not to OBSCURED since it affects input, not display. BUG=none TEST=It compiles. Ship it. Review URL: http://codereview.chromium.org/9117012 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@118796 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/views/view_unittest.cc')
-rw-r--r--ui/views/view_unittest.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/views/view_unittest.cc b/ui/views/view_unittest.cc
index 45e7dbd..79ef2fd 100644
--- a/ui/views/view_unittest.cc
+++ b/ui/views/view_unittest.cc
@@ -897,7 +897,7 @@ TEST_F(ViewTest, TextfieldCutCopyPaste) {
Textfield* normal = new Textfield();
Textfield* read_only = new Textfield();
read_only->SetReadOnly(true);
- Textfield* password = new Textfield(Textfield::STYLE_PASSWORD);
+ Textfield* password = new Textfield(Textfield::STYLE_OBSCURED);
root_view->AddChildView(normal);
root_view->AddChildView(read_only);
@@ -957,7 +957,7 @@ TEST_F(ViewTest, TextfieldCutCopyPaste) {
::SendMessage(password->GetTestingHandle(), WM_COPY, 0, 0);
result.clear();
clipboard.ReadText(ui::Clipboard::BUFFER_STANDARD, &result);
// We don't let you copy from a password field, clipboard should not have
// changed.
EXPECT_EQ(kNormalText, result);
@@ -957,7 +957,7 @@ TEST_F(ViewTest, TextfieldCutCopyPaste) {
result.clear();
clipboard.ReadText(ui::Clipboard::BUFFER_STANDARD, &result);
- // We don't let you copy from a password field, clipboard should not have
+ // We don't let you copy from an obscured field, clipboard should not have
// changed.
EXPECT_EQ(kNormalText, result);